unit Main;

interface

{$IFDEF VER130} {$DEFINE DELPHI5} {$ENDIF}

uses
  Windows, Messages, SysUtils, {$IFNDEF DELPHI5}Variants,{$ENDIF} Classes, Graphics, Controls, Forms, {$IFNDEF DELPHI5}StrUtils,{$ENDIF}
  Dialogs, StdCtrls, dFlickr, ExtCtrls;

type
  TMainForm = class(TForm)
    MemoResponse: TMemo;
    EdtAPIKey: TEdit;
    Label1: TLabel;
    Button2: TButton;
    EdtTestEmail: TEdit;
    Bevel1: TBevel;
    Label2: TLabel;
    Button3: TButton;
    Button4: TButton;
    Bevel2: TBevel;
    EdtCatId: TEdit;
    Label5: TLabel;
    Button5: TButton;
    Button6: TButton;
    Button1: TButton;
    Bevel3: TBevel;
    Label6: TLabel;
    EdtPhotoPath: TEdit;
    Button7: TButton;
    Button8: TButton;
    OpenDlg: TOpenDialog;
    Label3: TLabel;
    edtSharedSecret: TEdit;
    Label4: TLabel;
    edtToken: TEdit;
    chkUseAuthentication: TCheckBox;
    cbxAuthLevel: TComboBox;
    procedure Button8Click(Sender: TObject);
    procedure Button7Click(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Button6Click(Sender: TObject);
    procedure Button5Click(Sender: TObject);
    procedure Button4Click(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);

    function GetFlickr : TFlickr;
    procedure FormCreate(Sender: TObject);
  private
    procedure DisplayPhotoList(PhotoList: TFlickrPhotoList);
    procedure DisplayPeopleList(PeopleList: TFlickrPeopleList);
    procedure DisplayTagList(TagList: TFlickrTagList);
    procedure DisplayGroupList(GroupList: TFlickrGroupList);
    function Pad(Str: string; Padding: Integer): string;
  end;

var
  MainForm: TMainForm;

{$IFDEF DELPHI5}
function DupeString(ch : Char; len : Integer) : String;
{$ENDIF}

implementation

{$R *.dfm}

{$IFDEF DELPHI5}
function DupeString(ch : Char; len : Integer) : String;
var
  i : Integer;
begin
  result:='';
  for i:=1 to len do
    result:=result+ch;
end;
{$ENDIF}

function TMainForm.Pad(Str: string; Padding: Integer): string;
begin
  Result := Str + DupeString(' ', Padding - Length(Str));
end;

procedure TMainForm.DisplayPhotoList(PhotoList: TFlickrPhotoList);
var
  i: Integer;
begin
  MemoResponse.Lines.Add('Page   : ' + IntToStr(PhotoList.Page));
  MemoResponse.Lines.Add('Pages  : ' + IntToStr(PhotoList.Pages));
  MemoResponse.Lines.Add('PerPage: ' + IntToStr(PhotoList.PerPage));
  MemoResponse.Lines.Add('Total  : ' + IntToStr(PhotoList.Total));
  MemoResponse.Lines.Add(Pad('ID', 15) + ' - TITLE');
  for i := 0 to PhotoList.Count - 1 do
    MemoResponse.Lines.Add(Pad(PhotoList.GetPhoto(i).Id, 15) + ' - ' + PhotoList.GetPhoto(i).Title);
end;

procedure TMainForm.DisplayPeopleList(PeopleList: TFlickrPeopleList);
var
  i: Integer;
begin
  MemoResponse.Lines.Add(Pad('ID', 15) + ' - USERNAME');
  for i := 0 to PeopleList.Count - 1 do
    MemoResponse.Lines.Add(Pad(PeopleList.GetPeople(i).Id, 15) + ' - ' + PeopleList.GetPeople(i).Username);
end;

procedure TMainForm.DisplayTagList(TagList: TFlickrTagList);
var
  i: Integer;
begin
  for i := 0 to TagList.Count - 1 do
    MemoResponse.Lines.Add(TagList.GetTag(i).Text);
end;

procedure TMainForm.DisplayGroupList(GroupList: TFlickrGroupList);
var
  i: Integer;
begin
  MemoResponse.Lines.Add('CATEGORIES:');
  MemoResponse.Lines.Add(Pad('ID', 15) + ' - NAME');
  for i := 0 to GroupList.GroupCatCount - 1 do
    MemoResponse.Lines.Add(Pad(GroupList.GetGroupCat(i).Id, 15) + ' - ' + GroupList.GetGroupCat(i).Name);
  MemoResponse.Lines.Add('GROUPS:');
  MemoResponse.Lines.Add(Pad('ID', 15) + ' - NAME');
  for i := 0 to GroupList.GroupCount - 1 do
    MemoResponse.Lines.Add(Pad(GroupList.GetGroup(i).Id, 15) + ' - ' + GroupList.GetGroup(i).Name);
end;

function TMainForm.GetFlickr : TFlickr;
var
  Flickr: TFlickr;
begin
  // simple wrapper around flickr authentication call

  Flickr := TFlickr.Create(edtAPIKey.Text, edtSharedSecret.Text);
  if chkUseAuthentication.Checked then
  begin
    if not Flickr.CheckToken(edtToken.Text, cbxAuthLevel.Items[cbxAuthLevel.ItemIndex]) then
    begin
      MemoResponse.Lines.Add('Error: Invalid Token');
      Exit;
    end
    else
    begin
      if Flickr.Token<>edtToken.Text then
      begin
        edtToken.Text:=Flickr.Token;
        memoResponse.Lines.Add('Updated token');
      end;
    end;
  end;

  Result := Flickr;
end;

procedure TMainForm.Button2Click(Sender: TObject);
var
  Flickr: TFlickr;
  People: TFlickrPeople;
begin
  Flickr := GetFlickr;
  try
    try
      People := nil;
      People := Flickr.PeopleFindByEmail(EdtTestEmail.Text);
      MemoResponse.Lines.Add('Id      : ' + People.Id);
      MemoResponse.Lines.Add('Username: ' + People.Username);
      MemoResponse.Lines.Add('Realname: ' + People.Realname);
      MemoResponse.Lines.Add('Location: ' + People.Location);
    except
      on E: Exception do MemoResponse.Lines.Add('Error: ' + E.Message);
    end;
    if People <> nil then People.Free;

    MemoResponse.Lines.Add('------------------------------');
  finally
    Flickr.Free;
  end;
end;

procedure TMainForm.Button3Click(Sender: TObject);
var
  Flickr: TFlickr;
  People: TFlickrPeople;
  PhotoList: TFlickrPhotoList;
begin
  Flickr := GetFlickr;

  try
    People := nil;
    PhotoList := nil;
    People := Flickr.PeopleFindByEmail(EdtTestEmail.Text);
    PhotoList := Flickr.PhotosSearch(People.Id);
    DisplayPhotoList(PhotoList);
  except
    on E: Exception do MemoResponse.Lines.Add('Error: ' + E.Message);
  end;
  if People <> nil then People.Free;
  if PhotoList <> nil then PhotoList.Free;

  MemoResponse.Lines.Add('------------------------------');
  Flickr.Free;
end;

procedure TMainForm.Button4Click(Sender: TObject);
var
  Flickr: TFlickr;
  People: TFlickrPeople;
begin
  Flickr := GetFlickr;

  try
    People := nil;
    People := Flickr.PeopleFindByEmail(EdtTestEmail.Text);
    DisplayTagList(People.Tags);
  except
    on E: Exception do MemoResponse.Lines.Add('Error: ' + E.Message);
  end;
  if People <> nil then People.Free;

  MemoResponse.Lines.Add('------------------------------');
  Flickr.Free;
end;

procedure TMainForm.Button5Click(Sender: TObject);
var
  Flickr: TFlickr;
  GroupList: TFlickrGroupList;
begin
  Flickr := GetFlickr;

  try
    GroupList := nil;
    GroupList := Flickr.GroupsBrowse(EdtCatId.Text);
    DisplayGroupList(GroupList);
  except
    on E: Exception do MemoResponse.Lines.Add('Error: ' + E.Message);
  end;
  if GroupList <> nil then GroupList.Free;

  MemoResponse.Lines.Add('------------------------------');
  Flickr.Free;
end;

procedure TMainForm.Button6Click(Sender: TObject);
var
  Flickr: TFlickr;
  People: TFlickrPeople;
  i: Integer;
begin
  Flickr := GetFlickr;

  try
    People := nil;
    People := Flickr.PeopleFindByEmail(EdtTestEmail.Text);
    for i := 0 to People.Photosets.Count - 1 do
    begin
      MemoResponse.Lines.Add('PHOTOSET ' + People.Photosets.GetPhotoset(i).Title +
                             '(' + IntToStr(People.Photosets.GetPhotoset(i).Photos.Count) +
                             ' photos):');
      DisplayPhotoList(People.Photosets.GetPhotoset(i).Photos);
    end;
  except
    on E: Exception do MemoResponse.Lines.Add('Error: ' + E.Message);
  end;
  if People <> nil then People.Free;

  MemoResponse.Lines.Add('------------------------------');
  Flickr.Free;
end;

procedure TMainForm.Button1Click(Sender: TObject);
var
  Flickr: TFlickr;
  People: TFlickrPeople;
begin
  Flickr := GetFlickr;

  try
    People := nil;
    People := Flickr.PeopleFindByEmail(EdtTestEmail.Text);
    DisplayPeopleList(people.PublicContacts);
  except
    on E: Exception do MemoResponse.Lines.Add('Error: ' + E.Message);
  end;
  if People <> nil then People.Free;

  MemoResponse.Lines.Add('------------------------------');
  Flickr.Free;
end;

procedure TMainForm.Button8Click(Sender: TObject);
begin
  if OpenDlg.Execute then
    EdtPhotoPath.Text := Opendlg.FileName;
end;

procedure TMainForm.Button7Click(Sender: TObject);
var
  Flickr: TFlickr;
  Photo: TFlickrPhoto;
begin
  Flickr := GetFlickr;

  try
    Photo := nil;
    Photo := Flickr.Upload(EdtPhotoPath.Text);
    MemoResponse.Lines.Add('Photo uploaded, title=' + Photo.Title);
  except
    on E: Exception do MemoResponse.Lines.Add('Error: ' + E.Message);
  end;
  if Photo <> nil then Photo.Free;

  MemoResponse.Lines.Add('------------------------------');
  Flickr.Free;
end;

procedure TMainForm.FormCreate(Sender: TObject);
begin
  cbxAuthLevel.ItemIndex:=0;  // default to read
end;

end.